@@ -5,9 +5,9 @@
 # Copyright (C) 1995,1996 Neil Bowers.  All rights reserved.
 #
 # See README for additional blurb.
-# Bugs, comments, suggestions welcome: neilb@khoral.com
+# Bugs, comments, suggestions welcome: neilb@cre.canon.co.uk
 #
-$VERSION	= '1.009';
+$VERSION	= '1.010';
 ($PROGRAM = $0) =~ s@.*/@@;
 $FILENAME	= 'testfile.htm';
 $LOGFILE	= 'test.log';
@@ -208,7 +208,6 @@ $ENV{WEBLINTRC} = '/dev/null';
 	    5, 'extension-markup',
 	    5, 'extension-markup',
 	    6, 'extension-markup',
-	    6, 'attribute-format',	# hmm, checking tags of unknown elts?
 	    6, 'extension-markup');
 
 &ExpectOK('Netscape tags *with* Netscape extension enabled', '-x Netscape',
@@ -222,8 +221,8 @@ $ENV{WEBLINTRC} = '/dev/null';
 &ExpectWARN('not allowed to nest FORM elements', '',
 	    "<HTML>\n<HEAD><TITLE>title</TITLE></HEAD>\n".
 	    "<BODY>\n".
-	    "<FORM METHOD=post ACTION=\"http://www.khoral.com/foo\">\n".
-	    "<FORM METHOD=post ACTION=\"http://www.khoral.com/foo\">\n".
+	    "<FORM METHOD=post ACTION=\"http://www.cre.canon.co.uk/foo\">\n".
+	    "<FORM METHOD=post ACTION=\"http://www.cre.canon.co.uk/foo\">\n".
 	    "This is inside the nested form".
 	    "</FORM>\n".
 	    "</FORM></BODY></HTML>",
@@ -443,9 +442,12 @@ $ENV{WEBLINTRC} = '/dev/null';
 	  "<BODY>this is the body</BODY>\n</HTML>");
 
 &ExpectWARN('should use &gt; in place of >', '',
-	    "<HTML>\n<HEAD><TITLE>test</TITLE></HEAD>\n".
-	    "<BODY>text with > instead of &gt;</BODY>\n</HTML>",
-	    3, 'literal-metacharacter');
+	    "<HTML>\n".
+	    "<HEAD><TITLE>test</TITLE></HEAD>\n".
+	    "<BODY>\n".
+	    "text with > instead of &gt;\n".
+	    "</BODY>\n</HTML>",
+	    4, 'literal-metacharacter');
 
 &ExpectOK('IMG element with LOWSRC attribute', '-x Netscape',
 	  "<HTML>\n<HEAD><TITLE>test</TITLE></HEAD>\n".
@@ -543,7 +545,7 @@ $ENV{WEBLINTRC} = '/dev/null';
 &ExpectOK('FORM element with SELECT element which has SIZE attribute', '',
 	  "<HTML>\n<HEAD><TITLE>title</TITLE></HEAD>\n".
 	  "<BODY>\n".
-	  "<FORM METHOD=post ACTION=\"http://www.khoral.com/foo\">\n".
+	  "<FORM METHOD=post ACTION=\"http://www.cre.canon.co.uk/foo\">\n".
 	  "<SELECT NAME=\"foobar\" SIZE=\"50,8\">\n".
 	  "<OPTION>foobar\n".
 	  "</SELECT>\n".
@@ -790,7 +792,7 @@ $ENV{WEBLINTRC} = '/dev/null';
 	    "</PRE>\n".
 	    "</BODY>\n".
 	    "</HTML>",
-	    7, 'meta-in-pre');
+	    5, 'meta-in-pre');
 
 &ExpectWARN('heading inside an anchor', '',
 	    "<HTML>\n".
@@ -863,6 +865,49 @@ $ENV{WEBLINTRC} = '/dev/null';
 	  "</BODY>\n".
 	  "</HTML>");
 
+&ExpectWARN('use of > multiple times in a PRE element', '',
+	    "<HTML>\n".
+	    "<HEAD><TITLE>test</TITLE></HEAD>\n".
+	    "<BODY>\n".
+	    "<PRE>\n".
+	    "   if (x > y)\n".
+	    "      foobar();\n".
+	    "   if (x > z)\n".
+	    "      barfoo();\n".
+	    "</PRE>\n".
+	    "</BODY>\n".
+	    "</HTML>\n",
+	    5, 'meta-in-pre',
+	    7, 'meta-in-pre');
+
+&ExpectWARN("don't check attributes of unknown elements", '',
+	    "<HTML>\n".
+	    "<HEAD><TITLE>test</TITLE></HEAD>\n".
+	    "<BODY>\n".
+	    "Hello, <FONT SIZE=\"+1\">World!</FONT>\n".
+	    "</BODY>\n".
+	    "</HTML>\n",
+	    4, 'extension-markup',
+	    4, 'extension-markup');
+
+&ExpectOK('images with all variants of ALIGN for Netscape', '-x Netscape',
+	  "<HTML>\n".
+	  "<HEAD>\n".
+	  "<TITLE>test</TITLE>\n".
+	  "</HEAD>\n".
+	  "<BODY>\n".
+	  "<IMG SRC=\"foo.gif\" ALT=\"\" ALIGN=LEFT>\n".
+	  "<IMG SRC=\"foo.gif\" ALT=\"\" ALIGN=RIGHT>\n".
+	  "<IMG SRC=\"foo.gif\" ALT=\"\" ALIGN=TOP>\n".
+	  "<IMG SRC=\"foo.gif\" ALT=\"\" ALIGN=TEXTTOP>\n".
+	  "<IMG SRC=\"foo.gif\" ALT=\"\" ALIGN=MIDDLE>\n".
+	  "<IMG SRC=\"foo.gif\" ALT=\"\" ALIGN=ABSMIDDLE>\n".
+	  "<IMG SRC=\"foo.gif\" ALT=\"\" ALIGN=BASELINE>\n".
+	  "<IMG SRC=\"foo.gif\" ALT=\"\" ALIGN=BOTTOM>\n".
+	  "<IMG SRC=\"foo.gif\" ALT=\"\" ALIGN=ABSBOTTOM>\n".
+	  "</BODY>\n".
+	  "</HTML>");
+
 &WeblintTestEnd();
 
 
